import { Connect } from '@genesislcap/foundation-comms';
import { Datasource } from '@genesislcap/foundation-comms';
import { ElementStyles } from '@microsoft/fast-element';
import { FASTElement } from '@microsoft/fast-element';
import type { ServerRow } from '@genesislcap/foundation-comms';
import { ViewTemplate } from '@microsoft/fast-element';

/**
 * @public
 */
export declare const foundationServicesStatusStyles: ElementStyles;

/**
 * @public
 */
export declare const getPrefixedServicesStatus: (designSystemPrefix: string, templates?: ServiceStatusGetTemplateParmas) => ViewTemplate<ServicesStatus, any>;

/**
 * @internal
 * Default timeout for closing message
 */
export declare const SERVICE_STATUS_CLOSE_TIMEOUT = 10000;

/**
 * @public
 * Events names
 */
export declare const SERVICE_STATUS_EVENTS_NAMES: {
    readonly SERVICES_CHANGED: "servicesChanged";
    readonly SERVICE_FAIL: "serviceFail";
    readonly SERVICE_RESTORED: "serviceRestored";
    readonly CLOSE_MESSAGE: "dismiss";
    readonly AUTO_CLOSE_MESSAGE: "autoDismiss";
};

/**
 * @internal
 * Prefix for logger
 */
export declare const SERVICE_STATUS_LOGGER_PREFIX = "FoundationServicesStatus - ";

/**
 * Represents an individual service with basic information necessary for status tracking.
 * @public
 */
export declare interface ServiceItem {
    id: string;
    name: string;
    isWorking: boolean;
}

/**
 * Extends the basic server row with detailed information specific to a service process, including status, resources, and operational flags.
 * @internal
 */
export declare interface ServiceServerItem extends ServerRow {
    PROCESS_PORT: number;
    START_TIME: string;
    PROCESS_STATUS: boolean;
    PROCESS_ENABLED: boolean;
    PROCESS_SECURE: boolean;
    PROCESS_STATE_TEXT: string;
    DATADUMP: boolean;
    PROCESS_RESOURCES: string;
    PROCESS_MEM_USAGE: number;
    PROCESS_CPU_USAGE: number;
    PROCESS_NAME: string;
    PROCESS_STATUS_MESSAGE: string;
    LOG_LEVEL: string;
    PROCESS_HOSTNAME: string;
}

/**
 * The `ServicesStatus` component is designed to monitor and display the status of various services in real-time.
 * It leverages a connection to a backend datasource to receive updates about services status
 * and displays these updates to the user.
 *
 * @public
 */
export declare class ServicesStatus extends FASTElement {
    connect: Connect;
    datasource: Datasource;
    allMessages: ServiceItem[];
    allMessagesChanged(): void;
    displayMessages: ServiceItem[];
    resourceName: string;
    closeTimeout: ServicesStatusConfig['closeTimeout'];
    autoClose: ServicesStatusConfig['autoClose'];
    maxMessages: ServicesStatusConfig['maxMessages'];
    maxMessagesChanged(): void;
    messageRestored: string;
    messageFailed: string;
    titleRestored: string;
    titleFailed: string;
    eventNameCloseMessage: "dismiss";
    eventNameAutoCloseMessage: "autoDismiss";
    private datasourceSubscription;
    connectedCallback(): void;
    disconnectedCallback(): void;
    addMessage(newMessage: ServiceItem | ServiceItem[]): void;
    private updateDisplayMessages;
    private prepareServiceItem;
    private startMonitoring;
    private handleDataStream;
    stopMonitoring(): void;
    private closeMessageHandler;
    emitCloseMessage(target: any, identifier: any): void;
    private replaceTextPlaceholders;
    getTextHelper: (textType: ServiceStatusHelperText, type: ServiceStatusAvailableTypes, item: ServiceItem) => string;
}

/**
 * Configuration options for service status, including behavior around automatic closure and timeouts.
 * @public
 */
export declare interface ServicesStatusConfig {
    autoClose: boolean;
    closeTimeout: number;
    maxMessages: number;
}

/**
 * Represents the available types of service status messages.
 * @public
 */
export declare type ServiceStatusAvailableTypes = 'restored' | 'failed';

/**
 * Parameters for template functions used in service status messaging, providing hooks for restoration and failure handling.
 * @public
 */
export declare interface ServiceStatusGetTemplateParmas {
    restored: (prefix: string, item: ServiceItem) => any;
    failed: (prefix: string, item: ServiceItem) => any;
}

/**
 * Type helper for the service status helper text generation.
 * @internal
 */
export declare type ServiceStatusHelperText = 'title' | 'message';

/**
 * ZeroServicesStatus.
 *
 * @remarks
 * A zero version that pre-registers zero components and uses the zero design system.
 *
 * @example
 * ```ts
 * import { ZeroServicesStatus } from '@genesislcap/foundation-services-status';
 * ...
 * ZeroServicesStatus
 * ```
 *
 * @example Load the micro frontend on-demand
 * ```ts

 *   const { ZeroServicesStatus } = await import('@genesislcap/foundation-services-status');
 *   return ZeroServicesStatus;
 * },
 * ```
 *
 * @public
 */
export declare class ZeroServicesStatus extends ServicesStatus {
    /**
     * @internal
     */
    connectedCallback(): Promise<void>;
    /**
     * @internal
     */
    protected loadRemotes(): Promise<void>;
}

export { }
